#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 either
version:              5.0.3
visibility:           public
id:                   either-5.0.3-DAFixdA0EjEqx9uv0mesY
key:                  either-5.0.3-DAFixdA0EjEqx9uv0mesY
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/either/
synopsis:             Combinators for working with sums
description:          Combinators for working with sums.
category:             Control, Monads
abi:                  2c28eabdfc955195596eda271f645389
exposed:              True
exposed-modules:      Data.Either.Combinators Data.Either.Validation
import-dirs:          /usr/lib/ghc-9.6.6/site-local/either-5.0.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/either-5.0.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/either-5.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-either
hs-libraries:         HSeither-5.0.3-DAFixdA0EjEqx9uv0mesY
depends:
    base-4.18.2.1 bifunctors-5.6.3-89jmcxwpllCKfeMRRJuDet mtl-2.3.1
    profunctors-5.6.3-EcD9vqp4m2WJ3pGg9ot77Y
    semigroupoids-6.0.2-EM42hf7QGx74z9TdpT30mc

haddock-interfaces:   /usr/share/doc/haskell-either/html/either.haddock
haddock-html:         /usr/share/doc/haskell-either/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

